==> pv_prompt-1.9.tar.gz: pv_prompt-1.9/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "pv_prompt"
DESCRIPTION = "PowerView shades toolkit"
URL = "https://github.com/sander76/pv_prompt"
EMAIL = None
AUTHOR = "Sander Teunissen"
REQUIRES_PYTHON = ">=3.5.0"
VERSION = 1.9

# What packages are required for this module to be executed?
REQUIRED = [
    "prompt_toolkit",
    "aiopvapi",
    "pysmb",
    "asyncdns2",
    "pygments",
    "pyserial",
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}


# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember
# to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, "README.rst"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, NAME, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system(
            "{0} setup.py sdist bdist_wheel --universal".format(sys.executable)
        )

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=("tests",)),
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['mypackage'],
    # entry_points={
    #     'console_scripts': ['mycli=mymodule:cli'],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    entry_points={
        "console_scripts": [
            "pv_prompt=pv_prompt.async_prompt:main",
            "pv_dongle=pv_prompt.dongle.start:main",
        ]
    },
    # $ setup.py publish support.
    cmdclass={"upload": UploadCommand},
)


# def readme():
#     with open("README.rst") as f:
#         return f.read()
#
#
# setup(
#     name="pv_prompt",
#     long_description=readme(),
#     version=VERSION,
#     packages=["pv_prompt", "pv_prompt.dongle"],
#     url="https://github.com/sander76/pv_prompt",
#     author="Sander Teunissen",
#     classifiers=[
#         "Programming Language :: Python",
#         "Topic :: Software Development :: Libraries :: Python Modules",
#         "License :: OSI Approved :: BSD License",
#         "Operating System :: OS Independent",
#         "Development Status :: 5 - Production/Stable",
#         "Intended Audience :: Developers",
#         "Programming Language :: Python :: 3.5",
#         "Programming Language :: Python :: 3.6",
#     ],
#     description="PowerView shades toolkit",
#     install_requires=[
#         "prompt_toolkit",
#         "aiopvapi",
#         "pysmb",
#         "asyncdns2",
#         "pygments",
#         "pyserial",
#     ],
#     entry_points={
#         "console_scripts": [
#             "pv_prompt=pv_prompt.async_prompt:main",
#             "pv_dongle=pv_prompt.dongle.start:main",
#         ]
#     },
# )

==> pv_prompt-1.9.1.tar.gz: pv_prompt-1.9.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "pv_prompt"
DESCRIPTION = "PowerView shades toolkit"
URL = "https://github.com/sander76/pv_prompt"
EMAIL = None
AUTHOR = "Sander Teunissen"
REQUIRES_PYTHON = ">=3.5.0"
VERSION = "1.9.1"

# What packages are required for this module to be executed?
REQUIRED = [
    "prompt_toolkit",
    "aiopvapi",
    "pysmb",
    "asyncdns2",
    "pygments",
    "pyserial",
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}


# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember
# to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, NAME, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system(
            "{0} setup.py sdist bdist_wheel --universal".format(sys.executable)
        )

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=("tests",)),
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['mypackage'],
    # entry_points={
    #     'console_scripts': ['mycli=mymodule:cli'],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    entry_points={
        "console_scripts": [
            "pv_prompt=pv_prompt.async_prompt:main",
            "pv_dongle=pv_prompt.dongle.start:main",
        ]
    },
    # $ setup.py publish support.
    cmdclass={"upload": UploadCommand},
)
